@@ -20,7 +20,6 @@ module TextShow.Classes where
 #if __GLASGOW_HASKELL__ >= 708
 import           Data.Data (Typeable)
 #endif
-import           Data.Monoid.Compat ((<>))
 import qualified Data.Text         as TS (Text, singleton)
 import qualified Data.Text.IO      as TS (putStrLn, hPutStrLn)
 import qualified Data.Text.Lazy    as TL (Text, singleton)
@@ -31,6 +30,9 @@ import           Data.Text.Lazy.Builder (Builder, fromLazyText, fromString,
 
 import           GHC.Show (appPrec, appPrec1)
 
+import           Prelude ()
+import           Prelude.Compat
+
 import           System.IO (Handle)
 
 import           TextShow.Utils (toString, toText)
@@ -46,7 +48,7 @@ import           TextShow.Utils (toString, toText)
 -- to combine 'Builder's when creating 'TextShow' instances. As an example:
 --
 -- @
--- import Data.Monoid
+-- import Data.Semigroup
 -- import TextShow
 --
 -- data Example = Example Int Int
@@ -57,7 +59,7 @@ import           TextShow.Utils (toString, toText)
 -- If you do not want to create 'TextShow' instances manually, you can alternatively
 -- use the "TextShow.TH" module to automatically generate default 'TextShow'
 -- instances using Template Haskell, or the "TextShow.Generic" module to
--- quickly define 'TextShow' instances using 'genericShowbPrec'.
+-- quickly define 'TextShow' instances using "GHC.Generics".
 --
 -- /Since: 2/
 class TextShow a where
