@@ -1,3 +1,4 @@
+{-# LANGUAGE CPP                      #-}
 {-# LANGUAGE ForeignFunctionInterface #-}
 {-# LANGUAGE MagicHash                #-}
 {-# LANGUAGE TemplateHaskell          #-}
@@ -23,7 +24,7 @@ import Foreign.C.Types
 
 import GHC.Conc (BlockReason, ThreadStatus)
 import GHC.Conc.Sync (ThreadId(..))
-import GHC.Prim
+import GHC.Exts (Addr#, unsafeCoerce#)
 
 import Prelude ()
 import Prelude.Compat
@@ -32,9 +33,18 @@ import TextShow.Classes (TextShow(..))
 import TextShow.Foreign.C.Types ()
 import TextShow.TH.Internal (deriveTextShow)
 
+#if MIN_VERSION_base(4,14,0)
+import TextShow.Classes (showbParen)
+import GHC.Show (appPrec)
+#endif
+
 -- | /Since: 2/
 instance TextShow ThreadId where
-    showbPrec p t = fromString "ThreadId " <> showbPrec p (getThreadId t)
+    showbPrec p t =
+#if MIN_VERSION_base(4,14,0)
+      showbParen (p > appPrec) $
+#endif
+      fromString "ThreadId " <> showbPrec p (getThreadId t)
     {-# INLINE showbPrec #-}
 
 -- Temporary workaround until Trac #8281 is fixed
@@ -43,7 +53,7 @@ foreign import ccall unsafe "rts_getThreadId" getThreadId# :: Addr# -> CInt
 getThreadId :: ThreadId -> CInt
 getThreadId (ThreadId tid) = getThreadId# (unsafeCoerce# tid)
 
--- | /Since: 2/
-$(deriveTextShow ''ThreadStatus)
 -- | /Since: 2/
 $(deriveTextShow ''BlockReason)
+-- | /Since: 2/
+$(deriveTextShow ''ThreadStatus)
