@@ -1,6 +1,10 @@
-{-# LANGUAGE CPP               #-}
-{-# LANGUAGE OverloadedStrings #-}
-{-# LANGUAGE TemplateHaskell   #-}
+{-# LANGUAGE CPP                #-}
+{-# LANGUAGE OverloadedStrings  #-}
+{-# LANGUAGE StandaloneDeriving #-}
+{-# LANGUAGE TemplateHaskell    #-}
+#if __GLASGOW_HASKELL__ >= 806
+{-# LANGUAGE DerivingVia        #-}
+#endif
 {-# OPTIONS_GHC -fno-warn-orphans #-}
 {-|
 Module:      TextShow.Control.Exception
@@ -18,7 +22,6 @@ module TextShow.Control.Exception () where
 
 import Control.Exception.Base
 
-import Data.Monoid.Compat ((<>))
 import Data.Text.Lazy.Builder (fromString)
 #if MIN_VERSION_base(4,9,0)
 import Data.Text.Lazy.Builder (singleton)
@@ -32,14 +35,22 @@ import TextShow.FromStringTextShow (FromStringShow(..))
 import TextShow.TH.Internal (deriveTextShow)
 
 -- | /Since: 2/
+#if __GLASGOW_HASKELL__ >= 806
+deriving via FromStringShow SomeException instance TextShow SomeException
+#else
 instance TextShow SomeException where
     showbPrec p (SomeException e) = showbPrec p $ FromStringShow e
     {-# INLINE showbPrec #-}
+#endif
 
 -- | /Since: 2/
+#if __GLASGOW_HASKELL__ >= 806
+deriving via FromStringShow IOException instance TextShow IOException
+#else
 instance TextShow IOException where
     showb = showb . FromStringShow
     {-# INLINE showb #-}
+#endif
 
 -- | /Since: 2/
 instance TextShow ArithException where
@@ -132,6 +143,14 @@ instance TextShow CompactionFailed where
     showb (CompactionFailed why) = fromString ("compaction failed: " <> why)
 #endif
 
+#if MIN_VERSION_base(4,11,0)
+-- | Only available with @base-4.11.0.0@ or later.
+--
+-- /Since: 3.7.3/
+instance TextShow FixIOException where
+    showbPrec _ FixIOException = fromString "cyclic evaluation in fixIO"
+#endif
+
 -- | /Since: 2/
 instance TextShow Deadlock where
     showb Deadlock = "<<deadlock>>"
