@@ -1,6 +1,7 @@
 {-# LANGUAGE BangPatterns       #-}
 {-# LANGUAGE CPP                #-}
 {-# LANGUAGE MagicHash          #-}
+{-# LANGUAGE NamedFieldPuns     #-}
 {-# LANGUAGE TemplateHaskell    #-}
 {-|
 Module:      TextShow.TH.Internal
@@ -58,8 +59,8 @@ module TextShow.TH.Internal (
 import           Control.Monad (unless, when)
 import           Data.Foldable.Compat
 import           Data.List.Compat
-import qualified Data.List.NonEmpty as NE (reverse)
-import           Data.List.NonEmpty (NonEmpty(..), (<|))
+import qualified Data.List.NonEmpty.Compat as NE (reverse)
+import           Data.List.NonEmpty.Compat (NonEmpty(..), (<|))
 import qualified Data.Map as Map (fromList, keys, lookup, singleton)
 import           Data.Map (Map)
 import           Data.Maybe
@@ -73,8 +74,13 @@ import           Data.Text.Lazy.Builder (Builder, toLazyText)
 import qualified Data.Text.Lazy    as TL
 import qualified Data.Text.Lazy.IO as TL (putStrLn, hPutStrLn)
 
-import           GHC.Exts (Char(..), Double(..), Float(..), Int(..), Word(..))
-import           GHC.Prim (Char#, Double#, Float#, Int#, Word#)
+import           GHC.Exts ( Char(..), Double(..), Float(..), Int(..), Word(..)
+                          , Char#, Double#, Float#, Int#, Word#
+#if MIN_VERSION_base(4,13,0)
+                          , Int8#, Int16#, Word8#, Word16#
+                          , extendInt8#, extendInt16#, extendWord8#, extendWord16#
+#endif
+                          )
 import           GHC.Show (appPrec, appPrec1)
 
 import           Language.Haskell.TH.Datatype
@@ -458,23 +464,23 @@ deriveTextShowClass :: TextShowClass -> Options -> Name -> Q [Dec]
 deriveTextShowClass tsClass opts name = do
   info <- reifyDatatype name
   case info of
-    DatatypeInfo { datatypeContext = ctxt
-                 , datatypeName    = parentName
-                 , datatypeVars    = vars
-                 , datatypeVariant = variant
-                 , datatypeCons    = cons
+    DatatypeInfo { datatypeContext   = ctxt
+                 , datatypeName      = parentName
+                 , datatypeInstTypes = instTys
+                 , datatypeVariant   = variant
+                 , datatypeCons      = cons
                  } -> do
       (instanceCxt, instanceType)
-        <- buildTypeInstance tsClass parentName ctxt vars variant
+        <- buildTypeInstance tsClass parentName ctxt instTys variant
       (:[]) <$> instanceD (return instanceCxt)
                           (return instanceType)
-                          (showbPrecDecs tsClass opts vars cons)
+                          (showbPrecDecs tsClass opts instTys cons)
 
 -- | Generates a declaration defining the primary function corresponding to a
 -- particular class (showbPrec for TextShow, liftShowbPrec for TextShow1, and
 -- liftShowbPrec2 for TextShow2).
 showbPrecDecs :: TextShowClass -> Options -> [Type] -> [ConstructorInfo] -> [Q Dec]
-showbPrecDecs tsClass opts vars cons =
+showbPrecDecs tsClass opts instTys cons =
     [genMethod ShowbPrec (showbPrecName tsClass)]
     ++ if tsClass == TextShow && shouldGenTextMethods
           then [genMethod ShowtPrec 'showtPrec, genMethod ShowtlPrec 'showtlPrec]
@@ -490,7 +496,7 @@ showbPrecDecs tsClass opts vars cons =
     genMethod method methodName
       = funD methodName
              [ clause []
-                      (normalB $ makeTextShowForCons tsClass method opts vars cons)
+                      (normalB $ makeTextShowForCons tsClass method opts instTys cons)
                       []
              ]
 
@@ -501,30 +507,30 @@ makeShowbPrecClass :: TextShowClass -> TextShowFun -> Options -> Name -> Q Exp
 makeShowbPrecClass tsClass tsFun opts name = do
   info <- reifyDatatype name
   case info of
-    DatatypeInfo { datatypeContext = ctxt
-                 , datatypeName    = parentName
-                 , datatypeVars    = vars
-                 , datatypeVariant = variant
-                 , datatypeCons    = cons
+    DatatypeInfo { datatypeContext   = ctxt
+                 , datatypeName      = parentName
+                 , datatypeInstTypes = instTys
+                 , datatypeVariant   = variant
+                 , datatypeCons      = cons
                  } ->
       -- We force buildTypeInstance here since it performs some checks for whether
       -- or not the provided datatype can actually have showbPrec/liftShowbPrec/etc.
       -- implemented for it, and produces errors if it can't.
-      buildTypeInstance tsClass parentName ctxt vars variant
-        >> makeTextShowForCons tsClass tsFun opts vars cons
+      buildTypeInstance tsClass parentName ctxt instTys variant
+        >> makeTextShowForCons tsClass tsFun opts instTys cons
 
 -- | Generates a lambda expression for showbPrec/liftShowbPrec/etc. for the
 -- given constructors. All constructors must be from the same type.
 makeTextShowForCons :: TextShowClass -> TextShowFun -> Options -> [Type] -> [ConstructorInfo]
                     -> Q Exp
-makeTextShowForCons tsClass tsFun opts vars cons = do
+makeTextShowForCons tsClass tsFun opts instTys cons = do
     p       <- newName "p"
     value   <- newName "value"
     sps     <- newNameList "sp" $ fromEnum tsClass
     sls     <- newNameList "sl" $ fromEnum tsClass
     let spls       = zip sps sls
         spsAndSls  = interleave sps sls
-        lastTyVars = map varTToName $ drop (length vars - fromEnum tsClass) vars
+        lastTyVars = map varTToName $ drop (length instTys - fromEnum tsClass) instTys
         splMap     = Map.fromList $ zip lastTyVars spls
 
         makeFun
@@ -696,29 +702,29 @@ makeTextShowForArg p _ tsFun _ _ (ConT tyName) tyExpName =
     showPrecE = varE (showPrecName TextShow tsFun)
 
     showE :: Q Exp
-    showE | tyName == ''Char#   = showPrimE 'C# oneHashE
-          | tyName == ''Double# = showPrimE 'D# twoHashE
-          | tyName == ''Float#  = showPrimE 'F# oneHashE
-          | tyName == ''Int#    = showPrimE 'I# oneHashE
-          | tyName == ''Word#   = showPrimE 'W# twoHashE
-          | otherwise = showPrecE `appE` integerE p `appE` tyVarE
+    showE =
+      case Map.lookup tyName primShowTbl of
+        Just ps -> showPrimE ps
+        Nothing -> showPrecE `appE` integerE p `appE` tyVarE
 
-    -- Starting with GHC 7.10, data types containing unlifted types with derived Show
-    -- instances show hashed literals with actual hash signs, and negative hashed
-    -- literals are not surrounded with parentheses.
-    showPrimE :: Name -> Q Exp -> Q Exp
-    showPrimE con _hashE
-#if __GLASGOW_HASKELL__ >= 711
-      = infixApp (showPrecE `appE` integerE 0 `appE` (conE con `appE` tyVarE))
-                 [| (<>) |]
-                 _hashE
-#else
-      = showPrecE `appE` integerE p `appE` (conE con `appE` tyVarE)
+    showPrimE :: PrimShow -> Q Exp
+    showPrimE PrimShow{ primShowBoxer
+#if __GLASGOW_HASKELL__ >= 800
+                      , primShowPostfixMod, primShowConv
 #endif
+                      }
+#if __GLASGOW_HASKELL__ >= 800
+        -- Starting with GHC 8.0, data types containing unlifted types with
+        -- derived Show instances show hashed literals with actual hash signs,
+        -- and negative hashed literals are not surrounded with parentheses.
+      = primShowConv tsFun $ infixApp (primE 0) [| (<>) |] (primShowPostfixMod tsFun)
+#else
+      = primE p
+#endif
+      where
+        primE :: Int -> Q Exp
+        primE prec = showPrecE `appE` integerE prec `appE` primShowBoxer tyVarE
 
-    oneHashE, twoHashE :: Q Exp
-    oneHashE = varE (singletonName  tsFun) `appE` charE   '#'
-    twoHashE = varE (fromStringName tsFun) `appE` stringE "##"
 makeTextShowForArg p tsClass tsFun conName tvMap ty tyExpName =
     [| $(makeTextShowForType tsClass tsFun conName tvMap False ty) p $(varE tyExpName) |]
 
@@ -1214,6 +1220,81 @@ starKindStatusToName _             = Nothing
 catKindVarNames :: [StarKindStatus] -> [Name]
 catKindVarNames = mapMaybe starKindStatusToName
 
+-------------------------------------------------------------------------------
+-- PrimShow
+-------------------------------------------------------------------------------
+
+data PrimShow = PrimShow
+  { primShowBoxer      :: Q Exp -> Q Exp
+  , primShowPostfixMod :: TextShowFun -> Q Exp
+  , primShowConv       :: TextShowFun -> Q Exp -> Q Exp
+  }
+
+primShowTbl :: Map Name PrimShow
+primShowTbl = Map.fromList
+    [ (''Char#,   PrimShow
+                    { primShowBoxer      = appE (conE 'C#)
+                    , primShowPostfixMod = oneHashE
+                    , primShowConv       = \_ x -> x
+                    })
+    , (''Double#, PrimShow
+                    { primShowBoxer      = appE (conE 'D#)
+                    , primShowPostfixMod = twoHashE
+                    , primShowConv       = \_ x -> x
+                    })
+    , (''Float#,  PrimShow
+                    { primShowBoxer      = appE (conE 'F#)
+                    , primShowPostfixMod = oneHashE
+                    , primShowConv       = \_ x -> x
+                    })
+    , (''Int#,    PrimShow
+                    { primShowBoxer      = appE (conE 'I#)
+                    , primShowPostfixMod = oneHashE
+                    , primShowConv       = \_ x -> x
+                    })
+    , (''Word#,   PrimShow
+                    { primShowBoxer      = appE (conE 'W#)
+                    , primShowPostfixMod = twoHashE
+                    , primShowConv       = \_ x -> x
+                    })
+#if MIN_VERSION_base(4,13,0)
+    , (''Int8#,   PrimShow
+                    { primShowBoxer      = appE (conE 'I#) . appE (varE 'extendInt8#)
+                    , primShowPostfixMod = oneHashE
+                    , primShowConv       = mkNarrowE "narrowInt8#"
+                    })
+    , (''Int16#,  PrimShow
+                    { primShowBoxer      = appE (conE 'I#) . appE (varE 'extendInt16#)
+                    , primShowPostfixMod = oneHashE
+                    , primShowConv       = mkNarrowE "narrowInt16#"
+                    })
+    , (''Word8#,  PrimShow
+                    { primShowBoxer      = appE (conE 'W#) . appE (varE 'extendWord8#)
+                    , primShowPostfixMod = twoHashE
+                    , primShowConv       = mkNarrowE "narrowWord8#"
+                    })
+    , (''Word16#, PrimShow
+                    { primShowBoxer      = appE (conE 'W#) . appE (varE 'extendWord16#)
+                    , primShowPostfixMod = twoHashE
+                    , primShowConv       = mkNarrowE "narrowWord16#"
+                    })
+#endif
+    ]
+
+#if MIN_VERSION_base(4,13,0)
+mkNarrowE :: String -> TextShowFun -> Q Exp -> Q Exp
+mkNarrowE narrowStr tsFun e =
+  foldr (`infixApp` [| (<>) |])
+        (varE (singletonName tsFun) `appE` charE ')')
+        [ varE (fromStringName tsFun) `appE` stringE ('(':narrowStr ++ " ")
+        , e
+        ]
+#endif
+
+oneHashE, twoHashE :: TextShowFun -> Q Exp
+oneHashE tsFun = varE (singletonName tsFun)  `appE` charE '#'
+twoHashE tsFun = varE (fromStringName tsFun) `appE` stringE "##"
+
 -------------------------------------------------------------------------------
 -- Assorted utilities
 -------------------------------------------------------------------------------
