@@ -1,11 +1,8 @@
 {-# LANGUAGE CPP             #-}
+{-# LANGUAGE DeriveGeneric   #-}
 {-# LANGUAGE TemplateHaskell #-}
 {-# LANGUAGE TypeFamilies    #-}
 
-#if __GLASGOW_HASKELL__ >= 702
-{-# LANGUAGE DeriveGeneric   #-}
-#endif
-
 #if __GLASGOW_HASKELL__ >= 706
 {-# LANGUAGE DataKinds       #-}
 #endif
@@ -28,11 +25,9 @@ module Derived.Records (TyCon(..), TyFamily(..)) where
 import qualified Generics.Deriving.TH as Generics
 #endif
 
-#if __GLASGOW_HASKELL__ >= 702
 import           GHC.Generics (Generic)
-# if __GLASGOW_HASKELL__ >= 706
+#if __GLASGOW_HASKELL__ >= 706
 import           GHC.Generics (Generic1)
-# endif
 #endif
 
 import           Instances.Utils.GenericArbitrary (genericArbitrary)
@@ -55,11 +50,9 @@ infixl 4 :@:
 data TyCon a b = TyConPrefix { tc1 :: a, tc2  :: b }
                | (:@:)       { tc3 :: b, (##) :: a }
   deriving ( Show
-#if __GLASGOW_HASKELL__ >= 702
            , Generic
-# if __GLASGOW_HASKELL__ >= 706
+#if __GLASGOW_HASKELL__ >= 706
            , Generic1
-# endif
 #endif
            )
 
@@ -84,10 +77,8 @@ data instance TyFamily a b = TyFamilyPrefix { tf1 :: a, tf2   :: b }
 instance (Arbitrary a, Arbitrary b) => Arbitrary (TyCon a b) where
     arbitrary = genericArbitrary
 
-#if MIN_VERSION_template_haskell(2,7,0)
 instance (Arbitrary a, Arbitrary b) => Arbitrary (TyFamily a b) where
     arbitrary = genericArbitrary
-#endif
 
 -------------------------------------------------------------------------------
 
@@ -105,28 +96,22 @@ $(Generics.deriveMeta           ''TyCon)
 $(Generics.deriveRepresentable1 ''TyCon)
 #endif
 
-#if __GLASGOW_HASKELL__ < 702
-$(Generics.deriveRepresentable0 ''TyCon)
-#endif
-
-#if MIN_VERSION_template_haskell(2,7,0)
-# if !defined(NEW_FUNCTOR_CLASSES)
+#if !defined(NEW_FUNCTOR_CLASSES)
 $(deriveShow1 'TyFamilyPrefix)
-# else
+#else
 $(deriveShow1 'TyFamilyPrefix)
 $(deriveShow2 '(:!:))
-# endif
+#endif
 
 $(deriveTextShow  'TyFamilyPrefix)
 $(deriveTextShow1 '(:!:))
 $(deriveTextShow2 'TyFamilyPrefix)
 
-# if !defined(__LANGUAGE_DERIVE_GENERIC1__)
+#if !defined(__LANGUAGE_DERIVE_GENERIC1__)
 $(Generics.deriveMeta           'TyFamilyPrefix)
 $(Generics.deriveRepresentable1 '(:!:))
-# endif
+#endif
 
-# if __GLASGOW_HASKELL__ < 706
+#if __GLASGOW_HASKELL__ < 706
 $(Generics.deriveRepresentable0 'TyFamilyPrefix)
-# endif
 #endif
