@@ -22,6 +22,8 @@ Defines data types that use type synonyms.
 -}
 module Derived.TypeSynonyms (TyCon(..), TyFamily(..)) where
 
+import           Data.Orphans ()
+
 import qualified Generics.Deriving.TH as Generics
 
 import           GHC.Generics (Generic)
@@ -43,10 +45,6 @@ type FakeOut a = Int
 type Id a = a
 type Flip f a b = f b a
 
--- Needed for the Generic1 instances
-instance Functor ((,,,) a b c) where
-    fmap f (a, b, c, d) = (a, b, c, f d)
-
 -------------------------------------------------------------------------------
 
 newtype TyCon a b = TyCon
