@@ -17,7 +17,6 @@ Portability: GHC
 module Instances.Data.Text () where
 
 import Data.Text.Encoding.Error (UnicodeException(..))
-import Data.Text.Foreign (I16)
 import Data.Text.Lazy.Builder (Builder, fromString)
 
 #if MIN_VERSION_text(1,0,0)
@@ -37,15 +36,12 @@ import Instances.Utils.GenericArbitrary (genericArbitrary)
 import Prelude ()
 import Prelude.Compat
 
-import Test.QuickCheck (Arbitrary(..), arbitraryBoundedEnum)
+import Test.QuickCheck (Arbitrary(..))
 import Test.QuickCheck.Instances ()
 
 instance Arbitrary Builder where
     arbitrary = fromString <$> arbitrary
 
-instance Arbitrary I16 where
-    arbitrary = arbitraryBoundedEnum
-
 instance Arbitrary UnicodeException where
     arbitrary = genericArbitrary
 
