@@ -8,7 +8,7 @@
 
 {-|
 Module:      Instances.Data.Type.Coercion
-Copyright:   (C) 2014-2016 Ryan Scott
+Copyright:   (C) 2014-2017 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
@@ -22,11 +22,8 @@ module Instances.Data.Type.Coercion () where
 import Data.Coerce (Coercible)
 import Data.Type.Coercion (Coercion(..))
 
-import Prelude ()
-import Prelude.Compat
-
-import Test.QuickCheck (Arbitrary(..))
+import Test.QuickCheck (Arbitrary(..), arbitraryBoundedEnum)
 
 instance Coercible a b => Arbitrary (Coercion a b) where
-    arbitrary = pure Coercion
+    arbitrary = arbitraryBoundedEnum
 #endif
