@@ -10,7 +10,7 @@ Portability: GHC
 -}
 module Spec.Data.ProxySpec (main, spec) where
 
-import Data.Proxy (Proxy(..))
+import Data.Proxy.Compat (Proxy(..))
 
 import Generics.Deriving.Base ()
 
